This is a version of `Riverbank <http://www.riverbankcomputing.co.uk/>`_'s
`SIP <http://www.riverbankcomputing.co.uk/software/sip/intro>`_ which is installable in a Pythonic way (*easy_install* or
*pip*). The package's version is the same as Riverbank's SIP source package.

To spare Windows user's from the atrocities of a source installation in a virtualenv, a binary package is supplied.